---
myst:
  html_meta:
    "description": "cs_dynamicpages concepts"
    "property=og:description": "cs_dynamicpages concepts"
    "property=og:title": "cs_dynamicpages concepts"
    "keywords": "Plone, cs_dynamicpages, concepts"
---

# Concepts

This part of the documentation contains conceptual guides, including design defense and explanation of concepts for deeper study.
The Diátaxis framework also calls this class of documentation _explanation_.

> Explanation is a discursive treatment of a subject, that permits reflection.
> Explanation is understanding-oriented.

```{seealso}
https://diataxis.fr/explanation/
```

```{toctree}
:maxdepth: 2

architecture
```
